<?php

 /* #=======================================#
	# Создатель алгоритма Олег Исаев		#
	# ВКонтакте: vk.com/pandcar		 		#
	# Skype: pandcar97						#
	# -------------------------------------	#
	# Данный алгоритм является 				#
	# интеллектуальной собственностью, 		#
	# любое использование или демонстрация 	#
	# без разрешения правообладателя 		#
	# является нарушением закона. 			#
	#=======================================# */


/**
 * Вспомогательный системный класс PDO
 */
class PDOSysHelper
{
	public static $arr = array();
}

/**
 * Устанавливает новое соединение с базой данных MySQL
 *
 * @param  string $host 	Может быть именем хоста или IP адресом
 * @param  string $user 	Имя пользователя
 * @param  string $pass 	Пароль
 * @param  string $dbname 	База данных
 * @param  string $charset 	Кодировка соединения
 * @return object PDO
 */
function pdo_mysql_connect($host, $user, $pass, $dbname, $charset)
{
	return pdo_connect('mysql:host='.($host != '' ? $host : 'localhost').';dbname='.$dbname.';charset='.($charset != '' ? $charset : 'utf8'), $user, $pass);
}

/**
 * Устанавливает новое соединение с базой данных Oracle
 *
 * @param  string $host 	Может быть именем хоста или IP адресом
 * @param  string $user 	Имя пользователя
 * @param  string $pass 	Пароль
 * @param  string $dbname 	База данных
 * @param  string $charset 	Кодировка соединения
 * @return object PDO
 */
function pdo_oracle_connect($host, $user, $pass, $dbname, $charset)
{
	return pdo_connect('oci:dbname='.($host != '' ? $host : 'localhost').'/'.$dbname.';charset='.($charset != '' ? $charset : 'utf8'), $user, $pass);
}

/**
 * Устанавливает новое соединение с базой данных SQLite
 *
 * @param  string $path 	Путь к базе данных
 * @return object PDO
 */
function pdo_sqlite_connect($path)
{
	return pdo_connect('sqlite:'.$path, null, null);
}

/**
 * Устанавливает новое соединение с базой данных
 *
 * @param  string $dsn 		DSN
 * @param  string $user 	Имя пользователя для строки DSN
 * @param  string $pass		Пароль для строки DSN
 * @return object PDO
 */
function pdo_connect($dsn, $user, $pass)
{
	$opt = array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION, PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC);
	try
	{
		$pdo_object = new PDO($dsn, $user, $pass, $opt);
	}
	catch (PDOException $e)
	{
		$place 		= debug_backtrace();
		$msg_error 	= $place['0']['function'].'() in <b>'.$place['0']['file'].'</b> on line <b>'.$place['0']['line'].'</b>, description error: '.$e->getMessage();
		PDOSysHelper::$arr['error'][] = $msg_error;
		trigger_error($msg_error, E_USER_WARNING);
		return false;
	}
	PDOSysHelper::$arr['default'] = $pdo_object;
	return $pdo_object;
}

/**
 * Подготавливает и выполняет SQL запрос
 *
 * @param  string $sql 			Текст SQL запроса для подготовки и выполнения
 * @param  string $array_var 	Массив значений
 * @param  object $pdo_object	Объект PDO
 * @return object prepare-execute/query
 */
function pdo_query($sql, $array_var, $pdo_object)
{
	$pdo_object = is_object($pdo_object) ? $pdo_object : PDOSysHelper::$arr['default'];
	if (is_object($pdo_object))
	{
		try
		{
			if (is_array($array_var)) {
				$query_object = $pdo_object->prepare($sql);
				$query_object->execute($array_var);
			} else {
				$query_object = $pdo_object->query($sql);
			}
		}
		catch (PDOException $e)
		{
			$place 		= debug_backtrace();
			$msg_error 	= $place['0']['function'].'() in <b>'.$place['0']['file'].'</b> on line <b>'.$place['0']['line'].'</b>, description error: '.$e->getMessage();
			PDOSysHelper::$arr['error'][] = $msg_error;
			trigger_error($msg_error, E_USER_WARNING);
			return false;
		}
		return $query_object;
	}
	return false;
}

/**
 * Извлечение следующей строки из результирующего набора
 *
 * @param  object $query_object 	Объект PDO::query
 * @param  string $style 			Стиль возвращаемого массива
 * @return array Значение зависит от режима выборки
 */
function pdo_fetch($query_object, $style)
{
	return is_object($query_object) ? $query_object->fetch($style != '' ? $style : PDO::FETCH_ASSOC) : false;
}

/**
 * Возвращает массив, содержащий все строки результирующего набора
 *
 * @param  object $query_object 	Объект PDO::query
 * @param  string $style 			Стиль возвращаемого массива
 * @return array Значения зависят от режима выборки
 */
function pdo_fetch_all($query_object, $style)
{
	return is_object($query_object) ? $query_object->fetchAll($style != '' ? $style : PDO::FETCH_ASSOC) : false;
}

/**
 * Возвращает данные результата запроса
 *
 * @param  object $query_object 	Объект PDO::query
 * @param  string $key 				Номер получаемого ряда из результата
 * @return int/string Содержимое одного поля из набора результата
 */
function pdo_result($query_object, $key)
{
	if (is_object($query_object)) {
		$line = $query_object->fetch(PDO::FETCH_NUM);
		return $line[$key];
	}
	return false;
}

/**
 * Возвращает число строк в результате запроса
 *
 * @param  object $query_object 	Объект PDO::query
 * @return int Возвращает количество строк
 */
function pdo_num_rows($query_object)
{
	return is_object($query_object) ? $query_object->rowCount() : false;
}

/**
 * Возвращает количество столбцов в результирующем наборе
 *
 * @param  object $query_object 	Объект PDO::query
 * @return int Возвращает количество столбцов в результирующем наборе запроса
 */
function pdo_num_column($query_object)
{
	return is_object($query_object) ? $query_object->columnCount() : false;
}

/**
 * Возвращает ID последней вставленной строки
 *
 * @param  object $pdo_object	Объект PDO
 * @return int ID строки
 */
function pdo_insert_id($pdo_object)
{
	$pdo_object = is_object($pdo_object) ? $pdo_object : PDOSysHelper::$arr['default'];
	return is_object($pdo_object) ? $pdo_object->lastInsertId() : false;
}

/**
 * Заключает строку в кавычки для использования в запросе
 *
 * @param  string $string 		Строка
 * @param  object $pdo_object	Объект PDO
 * @return string Возвращает экранированную строку
 */
function pdo_quote($string, $pdo_object)
{
	$pdo_object = is_object($pdo_object) ? $pdo_object : PDOSysHelper::$arr['default'];
	return is_object($pdo_object) ? $pdo_object->quote($string) : false;
}

/**
 * Экранирует строку с помощью слешей
 *
 * @param  string $string 	Строка
 * @return string Возвращает экранированную строку
 */
function pdo_res($string)
{
	return addslashes($string);
}

/**
 * Получает расширенную информацию об ошибке, произошедшей в ходе последнего обращения к базе данных
 * 
 * @param  object $pdo_object	Объект PDO
 * @return string Текст ошибки
 */
function pdo_error($pdo_object)
{
	$pdo_object = is_object($pdo_object) ? $pdo_object : PDOSysHelper::$arr['default'];
	return is_object($pdo_object) ? implode(', ', $pdo_object->errorInfo()) : false;
}

/**
 * Возвращает массив ошибок
 *
 * @return array Возвращает массив ошибок
 */
function pdo_error_array()
{
	return is_object( is_array(PDOSysHelper::$arr['error']) ) ? PDOSysHelper::$arr['error'] : false;
}

/**
 * Освобождает память от результата запроса
 *
 * @param  object $query_object 	Объект PDO::query
 */
function pdo_free_result($query_object)
{
	unset($query_object);
}

/**
 * Закрывает ранее открытое соединение с базой данных
 *
 * @param  object $pdo_object	Объект PDO
 */
function pdo_close($pdo_object)
{
	$pdo_object = is_object($pdo_object) ? $pdo_object : PDOSysHelper::$arr['default'];
	unset($pdo_object);
	unset(PDOSysHelper::$arr['default']);
}

?>